# remirepo spec file for php-pecl-tensor
#
# SPDX-FileCopyrightText:  Copyright 2020-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package      php-pecl-tensor}

%global pecl_name        tensor
%global with_zts         0%{!?_without_zts:%{?__ztsphp:1}}
# After 20-json
%global ini_name         40-%{pecl_name}.ini

%global upstream_version 3.0.7
#global upstream_prever  alpha2
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../ext/configure

Summary:        Objects for scientific computing in PHP
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        MIT
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

Patch0:         tensor-headers.patch
Patch1:         tensor-libs.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires: (%{?scl_prefix}php-devel >= 8.0 with %{?scl_prefix}php-devel < 8.4)
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-json
BuildRequires:  openblas-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-json%{?_isa} 
Requires:       %{?scl_prefix}php-pdo%{?_isa} 

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}


%description
Tensor is a library and extension that provides objects for scientific
computing in PHP.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
sed -e 's/\r//' -i ext/config.m4
%patch -P0 -p1 -b .headers
%patch -P1 -p1 -b .libs

# Fix version
sed -e '/PHP_TENSOR_VERSION/s/3.0.5/%{version}/' -i ext/php_tensor.h

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_TENSOR_VERSION/{s/.* "//;s/".*$//;p}' ext/php_tensor.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif
cd ..

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

# see https://github.com/RubixML/Tensor/issues/42
export CFLAGS="%{optflags} -Wno-incompatible-pointer-types"

cd %{sources}/ext
%{__phpize}
sed -e 's/INSTALL_ROOT/DESTDIR/' -i build/Makefile.global

cd ../NTS
%configure \
    --enable-tensor \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --enable-tensor \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C %{sources}/NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C %{sources}/ZTS
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=json.so \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=json.so \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Apr  1 2025 Remi Collet <remi@remirepo.net> - 3.0.7-1
- update to 3.0.7
- raise dependency on PHP 8.0

* Fri Mar 28 2025 Remi Collet <remi@remirepo.net> - 3.0.6-1
- update to 3.0.6
- re-license spec file to CECILL-2.1
- open https://github.com/RubixML/Tensor/issues/49 PHP 7.4 build failure

* Tue Mar 19 2024 Remi Collet <remi@remirepo.net> - 3.0.5-1
- update to 3.0.5

* Mon Feb 19 2024 Remi Collet <remi@remirepo.net> - 1.10.1-2
- ignore incompatible-pointer-types errors, reported as
  https://github.com/RubixML/Tensor/issues/42

* Wed Sep 20 2023 Remi Collet <remi@remirepo.net> - 3.0.4-1
- update to 3.0.4
- build out of sources tree

* Tue Feb 28 2023 Remi Collet <remi@remirepo.net> - 3.0.3-1
- update to 3.0.3
- fix license

* Mon Apr  4 2022 Remi Collet <remi@remirepo.net> - 3.0.2-1
- update to 3.0.2

* Mon Jun  7 2021 Remi Collet <remi@remirepo.net> - 3.0.00-2
- update to 3.0.00 (stable, no change)

* Tue May 25 2021 Remi Collet <remi@remirepo.net> - 3.0.0-1
- update to 3.0.0 (beta)
- raise dependency on PHP 7.4

* Tue May 25 2021 Remi Collet <remi@remirepo.net> - 2.2.3-1
- update to 2.2.3

* Mon Mar  8 2021 Remi Collet <remi@remirepo.net> - 2.2.1-1
- update to 2.2.1

* Mon Mar  1 2021 Remi Collet <remi@remirepo.net> - 2.2.0-1
- update to 2.2.0

* Sun Feb 21 2021 Remi Collet <remi@remirepo.net> - 2.1.4-1
- update to 2.1.4

* Mon Feb 15 2021 Remi Collet <remi@remirepo.net> - 1.8.0~alpha2-1
- initial package
- open https://github.com/RubixML/Tensor/pull/11
  check for openblas headers
- open https://github.com/RubixML/Tensor/issues/12
  PHP 8 compatibility
